Attribute VB_Name = "DoubleStuff"
Option Explicit

' Format the value with the indicated number of significant digits.
Public Function ToSignificantDigits(ByVal value As Double, ByVal significant_digits As Integer) As String
Dim sign As Double
Dim power As Integer
Dim result As String
Dim test_string As String

    ' Save the value's sign.
    sign = Sgn(value)
    value = Abs(value)

    ' Get the value's power of 10.
    power = Int(Log10(value)) + 1

    ' Scale the value so it has no digits before the decimal point.
    value = value / 10 ^ power

    ' Round the value to remove non-significant digits.
    value = Round(value, significant_digits)

    ' Unscale the value.
    value = value * 10 ^ power

    ' Format as fixed point.
    result = Format$(value, "0.0000000000000000000000000000000000000000")
    
    ' Remove trailing 0s.
    result = RTrimChars(result, "0")

    ' Remove the leading 0s and the decimal
    ' point to get only the significant digits.
    test_string = RTrimChars(LTrimChars(result, "0."), ".")

    ' Add 0s to the result if needed to give
    ' the required number of significant digits.
    If significant_digits > Len(test_string) Then
        result = result & String$(significant_digits - Len(test_string), "0")
    End If

    ' Return the result.
    ToSignificantDigits = result
End Function

' Return the log base 10.
Public Function Log10(ByVal value As Double) As Double
    Log10 = Log(value) / Log(10)
End Function

' Remove the indicated characters from the left end of the string.
Public Function LTrimChars(ByVal value As String, ByVal chars As String)
Dim i As Integer

    ' Find the first character not in chars.
    i = 1
    Do While InStr(1, chars, Mid$(value, i, 1)) > 0
        i = i + 1
        If i > Len(value) Then
            LTrimChars = ""
            Exit Function
        End If
    Loop

    ' Return the rest of the string.
    LTrimChars = Mid$(value, i)
End Function

' Remove the indicated characters from the right end of the string.
Public Function RTrimChars(ByVal value As String, ByVal chars As String)
Dim i As Integer

    ' Find the first character not in chars.
    i = Len(value)
    Do While InStr(1, chars, Mid$(value, i, 1)) > 0
        i = i - 1
        If i < 1 Then
            RTrimChars = ""
            Exit Function
        End If
    Loop

    ' Return the rest of the string.
    RTrimChars = Mid$(value, 1, i)
End Function

' Remove the indicated characters from both ends of the string.
Public Function TrimChars(ByVal value As String, ByVal chars As String)
    TrimChars = RTrimChars(LTrimChars(value, chars), chars)
End Function

